@@ -20,7 +20,7 @@ mv aaa julius-simple
 
 # update binaries
 cd julius
-sh ./support/build-all.sh --without-sndfile
+sh ./support/build-all.sh
 mv build/bin/* ../bin
 mv build/lib/* ../lib
 mv build/include/* ../include
@@ -48,3 +48,4 @@ rm -f man/Makefile.in
 # finished
 rm -f julius
 echo '#### FINISHED, you should remove julius-ver directory manually ###'
+echo '#### Also copy "plugin" dir to "plugin-sample" and modify the Makefile'
